==> bigloo2.6b.tar.gz: bigloo2.6b/runtime/Eval/evprimop.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Eval/evprimop.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Apr 26 15:32:04 1995                          */
;*    Last change :  Thu Apr  3 06:20:31 2003 (serrano)                */
;*    -------------------------------------------------------------    */
;*    This module is only used to define all the interpeter primops.   */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __evprimop

   (option  (set! *unsafe-type* #t)
	    (set! *unsafe-arity* #t)
	    (set! *unsafe-range*  #t)
	    (set! *unsafe-struct* #t)
	    (set! *cflags-optim* ""))
   
   (import  __type
	    __bigloo
	    __error
	    __os
	    __bexit
	    __structure
	    __hash
	    __tvector
	    __bit
	    __binary
	    __foreign
	    __intext 
	    __dsssl
	    __ucs2
	    __unicode
	    __process
	    __socket
 	    __pregexp
	    __date
	    
	    __reader
  	    
	    __pp
	    __pp_circle
	    
	    __rgc

	    __lalr_driver
	    
            __eval
	    __expand

	    (evmeaning-notify-error __evmeaning)
	    (define-primop!     __evenv)
	    (define-primop-ref! __evenv)
	    (register-eval-srfi! __expander_srfi-0)
	    (args-parse-usage          __expander_args)
	    
	    __r4_booleans_6_1
	    __r4_equivalence_6_2
	    __r4_pairs_and_lists_6_3
	    __r4_symbols_6_4
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_strings_6_7
	    __r4_vectors_6_8
	    __r4_control_features_6_9
	    __r4_ports_6_10_1
	    __r4_input_6_10_2
	    __r4_output_6_10_3
	    __r5_control_features_6_4
	    __r5_macro_4_3_hygiene)
   
   (eval    (export-all)))

==> bigloo_2.7a-1.tar.gz: bigloo2.7a/runtime/Eval/evprimop.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Eval/evprimop.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Apr 26 15:32:04 1995                          */
;*    Last change :  Wed Sep  7 08:56:51 2005 (serrano)                */
;*    -------------------------------------------------------------    */
;*    This module is only used to define all the interpeter primops.   */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __evprimop

   (option  (set! *unsafe-type* #t)
	    (set! *unsafe-arity* #t)
	    (set! *unsafe-range*  #t)
	    (set! *unsafe-struct* #t)
	    (set! *cflags-optim* ""))
   
   (import  __type
	    __bigloo
	    __param
	    __error
	    __os
	    __bexit
	    __structure
	    __hash
	    __tvector
	    __bit
	    __binary
	    __foreign
	    __intext 
	    __dsssl
	    __ucs2
	    __unicode
	    __process
	    __socket
 	    __pregexp
	    __date
	    __custom
	    __trace
	    __base64
	    __md5
	    __mmap
	    __thread
	    
	    __reader
  	    
	    __pp
	    __pp_circle
	    
	    __rgc

	    __lalr_driver

            __eval
	    __expand
	    __library

	    __object
	    
	    (evmeaning-notify-error __everror)
	    (define-primop! __evenv)
	    (define-primop-ref! __evenv)
	    (register-eval-srfi! __expander_srfi-0)
	    (args-parse-usage __expander_args)
	    
	    __r4_booleans_6_1
	    __r4_equivalence_6_2
	    __r4_pairs_and_lists_6_3
	    __r4_symbols_6_4
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_strings_6_7
	    __r4_vectors_6_8
	    __r4_control_features_6_9
	    __r4_ports_6_10_1
	    __r4_input_6_10_2
	    __r4_output_6_10_3
	    __r5_control_features_6_4
	    __r5_macro_4_3_hygiene)
   
   (eval    (export-all)))
